--- old/usr/src/lib/libm/common/m9x/nexttoward.c	2019-06-06 20:40:31.498524721 +0000
+++ new/usr/src/lib/libm/common/m9x/nexttoward.c	2019-06-06 20:40:31.517667259 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -43,35 +44,30 @@
 #include "libm.h"
 
 #if defined(__sparc)
-
 static union {
 	unsigned i[2];
 	double d;
 } C[] = {
-	0x00100000, 0,
-	0x7fe00000, 0,
-	0x7fffffff, 0xffffffff
+	0x00100000, 0, 0x7fe00000, 0, 0x7fffffff, 0xffffffff
 };
 
-#define	tiny	C[0].d
-#define	huge	C[1].d
-#define	qnan	C[2].d
+#define	tiny		C[0].d
+#define	huge		C[1].d
+#define	qnan		C[2].d
 
 enum fcc_type {
-	fcc_equal = 0,
-	fcc_less = 1,
-	fcc_greater = 2,
-	fcc_unordered = 3
+	fcc_equal = 0, fcc_less = 1, fcc_greater = 2, fcc_unordered = 3
 };
 
 #ifdef __sparcv9
-#define	_Q_cmp	_Qp_cmp
+#define	_Q_cmp		_Qp_cmp
 #endif
 
 extern enum fcc_type _Q_cmp(const long double *, const long double *);
 
 double
-__nexttoward(double x, long double y) {
+__nexttoward(double x, long double y)
+{
 	union {
 		unsigned i[2];
 		double d;
@@ -80,9 +76,10 @@
 		unsigned i[4];
 		long double q;
 	} yy;
+
 	long double lx;
 	unsigned hx;
-	volatile double	dummy;
+	volatile double dummy;
 	enum fcc_type rel;
 
 	/*
@@ -97,6 +94,7 @@
 
 	/* check for each of four possible orderings */
 	rel = _Q_cmp(&lx, &y);
+
 	if (rel == fcc_unordered)
 		return (qnan);
 
@@ -106,11 +104,12 @@
 			xx.i[0] = yy.i[0];
 			return (xx.d);
 		}
+
 		return (x);
 	}
 
 	if (rel == fcc_less) {
-		if (hx == 0) {	/* x is zero */
+		if (hx == 0) {			/* x is zero */
 			xx.i[0] = 0;
 			xx.i[1] = 0x00000001;
 		} else if ((int)xx.i[0] >= 0) {	/* x is positive */
@@ -121,7 +120,7 @@
 				xx.i[0]--;
 		}
 	} else {
-		if (hx == 0) {	/* x is zero */
+		if (hx == 0) {			/* x is zero */
 			xx.i[0] = 0x80000000;
 			xx.i[1] = 0x00000001;
 		} else if ((int)xx.i[0] >= 0) {	/* x is positive */
@@ -135,6 +134,7 @@
 
 	/* raise exceptions as needed */
 	hx = xx.i[0] & ~0x80000000;
+
 	if (hx == 0x7ff00000) {
 		dummy = huge;
 		dummy *= huge;
@@ -145,42 +145,40 @@
 
 	return (xx.d);
 }
-
 #elif defined(__x86)
-
 static union {
 	unsigned i[2];
 	double d;
 } C[] = {
-	0, 0x00100000,
-	0, 0x7fe00000,
-};
+	0, 0x00100000, 0, 0x7fe00000, };
 
-#define	tiny	C[0].d
-#define	huge	C[1].d
+#define	tiny		C[0].d
+#define	huge		C[1].d
 
 double
-__nexttoward(double x, long double y) {
+__nexttoward(double x, long double y)
+{
 	union {
 		unsigned i[2];
 		double d;
 	} xx;
+
 	unsigned hx;
 	long double lx;
-	volatile double	dummy;
+	volatile double dummy;
 
 	lx = xx.d = x;
 	hx = (xx.i[1] & ~0x80000000) | xx.i[0];
 
 	/* check for each of four possible orderings */
 	if (isunordered(lx, y))
-		return ((double) (lx + y));
+		return ((double)(lx + y));
 
 	if (lx == y)
-		return ((double) y);
+		return ((double)y);
 
 	if (lx < y) {
-		if (hx == 0) {	/* x is zero */
+		if (hx == 0) {			/* x is zero */
 			xx.i[0] = 0x00000001;
 			xx.i[1] = 0;
 		} else if ((int)xx.i[1] >= 0) {	/* x is positive */
@@ -191,7 +189,7 @@
 				xx.i[1]--;
 		}
 	} else {
-		if (hx == 0) {	/* x is zero */
+		if (hx == 0) {			/* x is zero */
 			xx.i[0] = 0x00000001;
 			xx.i[1] = 0x80000000;
 		} else if ((int)xx.i[1] >= 0) {	/* x is positive */
@@ -205,6 +203,7 @@
 
 	/* raise exceptions as needed */
 	hx = xx.i[1] & ~0x80000000;
+
 	if (hx == 0x7ff00000) {
 		dummy = huge;
 		dummy *= huge;
@@ -215,7 +214,6 @@
 
 	return (xx.d);
 }
-
 #else
 #error Unknown architecture
 #endif
